require 'rails_helper'
require 'support/model_classes'
require 'support/factories'
require 'support/setup'
require 'pry'

describe "permission model mixin" do
  before(:each) do
    @permission = FactoryGirl.build(:can_read)
  end

  context "Validation checks" do
    it "should be valid" do
      expect(FactoryGirl.build(:can_read)).to be_valid
    end

    it "should not be valid" do
      FactoryGirl.build(:can_read, permission_name: '').should_not be_valid
    end
  end

  context "Fiendly ID" do
    it "should find by name" do
      permission = FactoryGirl.create(:can_read)
      Permission.find(permission.permission_name.parameterize).should_not eql nil
    end
  end

  context "Model specific methods" do
    it "should be able to alter a permission" do
      @permission.can_alter?.should eql true
    end

    it "should be able to delete a permission" do
      @permission.can_delete?.should eql true
    end
  end

  context "Roles" do
    it "should return roles for a permission" do
      permission = FactoryGirl.create(:can_read)
      admin = FactoryGirl.create(:admin_role)

      admin.add_permission = permission.permission_name

      expect(permission.roles).to_not be nil
    end
  end
end
